.. _depend:

Dependencies
============

  * StoSim is unix-only (for now at least, contact Nic if you want to help). So you'll need Mac OSX or any Linux system.
  * You need Python>=2.7
  * For distributing code across multiple CPUs, the file-based distribution package fjd is required. If you distribute jobs on a PBS-cluster, you do not need fjd.
  * For plotting, you need gnuplot and epstopdf (maybe a useful tip for some: On Debian-Linux, epstopdf is currently in the "texlive-extra-utils" package. On OSX, install gwTex via i-installer)
  * You need Gnu R installed for T-tests.


